@@ -1,17 +1,15 @@
 package Bencher;
 
 our $DATE = '2016-01-05'; # DATE
-our $VERSION = '0.20'; # VERSION
+our $VERSION = '0.21'; # VERSION
 
 use 5.010001;
 use strict;
 use warnings;
 use Log::Any::IfLOG '$log';
 
-use Benchmark::Dumb qw(timethese);
 use Data::Dmp;
 use List::MoreUtils qw(firstidx minmax uniq);
-use Time::HiRes qw(time);
 
 our %SPEC;
 
@@ -877,6 +875,8 @@ $SPEC{format_result} = {
     args_as => 'array',
 };
 sub format_result {
+    require POSIX;
+
     my $envres = shift;
 
     my $ff = $envres->[3]{'table.fields'};
@@ -887,7 +887,8 @@ sub format_result {
         for my $rit (@{$envres->[2]}) {
             delete $rit->{rate};
             if ($rit_baseline) {
-                $rit->{mod_overhead_time} = $rit->{time} - $rit_baseline->{time};
+                $rit->{mod_overhead_time} =
+                    $rit->{time} - $rit_baseline->{time};
             }
         }
         splice @$ff, (firstidx {$_ eq 'rate'} @$ff), 1;
@@ -914,10 +915,15 @@ sub format_result {
 
     if ($unit) {
         for my $rit (@{$envres->[2]}) {
-            # XXX format number of decimal digits of 'time' and 'rate'
-            # based on sigma
+            my $num_significant_digits =
+                $rit->{errors} == 0 ? 6 :
+                POSIX::round(log($rit->{time} / $rit->{errors})/log(10));
             $rit->{time} = sprintf(
-                "%.5f%s", $rit->{time} * $factor, $unit);
+                "%.${num_significant_digits}g%s",
+                $rit->{time} * $factor, $unit);
+            $rit->{rate} = sprintf(
+                "%.${num_significant_digits}g", $rit->{rate});
+            $rit->{errors} = sprintf("%.2g", $rit->{errors});
             if (exists $rit->{mod_overhead_time}) {
                 $rit->{mod_overhead_time} = sprintf(
                     "%.5f%s", $rit->{mod_overhead_time} * $factor, $unit);
@@ -1421,6 +1427,7 @@ sub bencher {
 
     if ($action =~ /\A(show-items-results|bench)\z/) {
         require Module::Load;
+        require Time::HiRes;
 
         my $participants = $parsed->{participants};
         $envres = [200, "OK", [], {}];
@@ -1535,7 +1542,7 @@ sub bencher {
                     ${"$mod\::VERSION"};
             }
             $envres->[3]{'func.sysload_before'} = [Sys::Load::getload()];
-            $envres->[3]{'_time_start'} = time();
+            $envres->[3]{'_time_start'} = Time::HiRes::time();
         }
 
         my $tres = Benchmark::Dumb::_timethese_guts(
@@ -1548,7 +1555,7 @@ sub bencher {
 
         if ($return_resmeta) {
             $envres->[3]{'func.elapsed_time'} =
-                time() - $envres->[3]{'_time_start'};
+                Time::HiRes::time() - $envres->[3]{'_time_start'};
             delete $envres->[3]{'_time_start'};
             $envres->[3]{'func.sysload_after'} = [Sys::Load::getload()];
         }
@@ -1646,7 +1653,7 @@ Bencher - A benchmark framework
 
 =head1 VERSION
 
-This document describes version 0.20 of Bencher (from Perl distribution Bencher), released on 2016-01-05.
+This document describes version 0.21 of Bencher (from Perl distribution Bencher), released on 2016-01-05.
 
 =head1 SYNOPSIS
 
